# -*- coding: utf-8 -*-

import numpy as np
import matplotlib.pyplot as plt

# Données du problème
Lambda = 0.037
Cp = 1500
Rho = 1.325
L = 1                       # Épaisseur de l'isolant
t_max = 20000               # Temps de fin d'intégration en secondes
N_t = 100                   # Nombre d'intervalles dans le temps
N_X = 5                     # Nombre d'intervalles dans l'espace
T_int = 20
T_ext = 5
K = Lambda/(Rho*Cp)         # Diffusivité thermique [Instruction 1]

# Discrétisation de l'espace et du temps
dx = L/N_X                  #[Instruction 2.1]
dt = t_max/N_t              #[Instruction 2.2]
Temp = np.zeros((N_t+1, N_X+1))

# Initialisation de la température
# Conditions initiales
Temp[0, 0] = T_int          #[Instruction 3.1]
for i in range(1, N_X+1):
    Temp[0, i] = T_ext      #[Instruction 3.2]

# Conditions aux limites
for n in range(1, N_t+1):
    Temp[n, 0] = T_int      #[Instruction 3.3]
    Temp[n, N_X] = T_ext    #[Instruction 3.4]

# Calcul des températures aux différents instants
for n in range(0, N_t):     #[Instruction 4.1]
    for i in range(1, N_X): #[Instruction 4.2]
        Temp[n+1, i] = dt * K / (dx)**2 * ( Temp[n, i+1] + Temp[n, i-1] - 2*Temp[n, i] ) + Temp[n, i]   #[Instruction 4.3]

# Création de la figure
fig = plt.figure()
# Création des abcisses
X = dx * np.array(range(0, N_X+1))
# Quatre courbes intermédiaires
plt.plot(X, Temp[0, :], c='b', label= 't = 0')
plt.plot(X, Temp[int((6000/t_max)*N_t), :], c='r', label= 't = 6000 s')
plt.plot(X, Temp[int((12000/t_max)*N_t), :], c='g', label= 't = 12000 s')
plt.plot(X, Temp[int((18000/t_max)*N_t), :], c='k', label= 't = 18000 s')

plt.xlabel('Distance selon x (en mm)')
plt.ylabel('Température (°C)')

plt.legend()
plt.show()